#ifndef PEONY_ICON_NAMES_H
#define PEONY_ICON_NAMES_H

/* Icons for places */
#define PEONY_ICON_COMPUTER		"computer"
#define PEONY_ICON_FAVORITE          "favorite"
#define PEONY_ICON_PERSONAL        "personal"
#define PEONY_ICON_DESKTOP		"user-desktop"
#define PEONY_ICON_FILESYSTEM	"drive-harddisk"
#define PEONY_ICON_FOLDER		"folder"
#define PEONY_ICON_FOLDER_REMOTE	"folder-remote"
#define PEONY_ICON_HOME		"user-home"
#define PEONY_ICON_NETWORK		"network-workgroup"
#define PEONY_ICON_NETWORK_SERVER	"network-server"
#define PEONY_ICON_SEARCH		"system-search"
#define PEONY_ICON_TRASH		"user-trash"
#define PEONY_ICON_TRASH_FULL	"user-trash-full"
#define PEONY_ICON_DELETE		"edit-delete"

#define PEONY_ICON_FOLDER_DESKTOP    "user-desktop"
#define PEONY_ICON_FOLDER_DOCUMENTS  "folder-documents"
#define PEONY_ICON_FOLDER_DOWNLOAD   "folder-download"
#define PEONY_ICON_FOLDER_MUSIC      "folder-music"
#define PEONY_ICON_FOLDER_PICTURES   "folder-pictures"
#define PEONY_ICON_FOLDER_PUBLIC_SHARE "folder-publicshare"
#define PEONY_ICON_FOLDER_TEMPLATES  "folder-templates"
#define PEONY_ICON_FOLDER_VIDEOS     "folder-videos"

/* Other icons */
#define PEONY_ICON_TEMPLATE		"text-x-generic-template"

#endif /* PEONY_ICON_NAMES_H */

